@@ -1,6 +1,6 @@
 __all__ = ('SmsMTSPoint',)
 
-from expressmoney_service.api import *
+from ...api import *
 
 PROJECT = 'expressmoney-service'
 SERVICE = 'services'
